@@ -864,7 +864,7 @@ gotweb_render_index(struct template *tp)
 			continue;
 
 		error = gotweb_load_got_path(c, repo_dir);
-		if (error && error->code == GOT_ERR_LONELY_PACKIDX) {
+		if (error && error->code != GOT_ERR_LONELY_PACKIDX) {
 			if (error->code != GOT_ERR_NOT_GIT_REPO)
 				log_warnx("%s: %s: %s", __func__,
 				    sd_dent[d_i]->d_name, error->msg);
