@@ -15,8 +15,6 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "got_compat.h"
-
 /* Error codes */
 #define GOT_ERR_OK		0
 #define GOT_ERR_ERRNO		1
@@ -186,6 +184,7 @@
 #define GOT_ERR_COMMIT_BAD_AUTHOR 166
 #define GOT_ERR_UID		167
 #define GOT_ERR_GID		168
+#define GOT_ERR_NO_PROG		169
 
 struct got_error {
         int code;
