@@ -62,103 +62,6 @@ static const struct got_capability write_capabilities[] = {
 	{ GOT_CAPA_DELETE_REFS, NULL },
 };
 
-const struct got_error *
-got_serve_parse_command(char **command, char **repo_path, const char *gitcmd)
-{
-	const struct got_error *err = NULL;
-	size_t len, cmdlen, pathlen;
-	char *path0 = NULL, *path, *abspath = NULL, *canonpath = NULL;
-	const char *relpath;
-
-	*command = NULL;
-	*repo_path = NULL;
-
-	len = strlen(gitcmd);
-
-	if (len >= strlen(GOT_SERVE_CMD_SEND) &&
-	    strncmp(gitcmd, GOT_SERVE_CMD_SEND,
-	    strlen(GOT_SERVE_CMD_SEND)) == 0)
-		cmdlen = strlen(GOT_SERVE_CMD_SEND);
-	else if (len >= strlen(GOT_SERVE_CMD_FETCH) &&
-	    strncmp(gitcmd, GOT_SERVE_CMD_FETCH,
-	    strlen(GOT_SERVE_CMD_FETCH)) == 0)
-		cmdlen = strlen(GOT_SERVE_CMD_FETCH);
-	else
-		return got_error(GOT_ERR_BAD_PACKET);
-
-	if (len <= cmdlen + 1 || gitcmd[cmdlen] != ' ')
-		return got_error(GOT_ERR_BAD_PACKET);
-
-	if (memchr(&gitcmd[cmdlen + 1], '\0', len - cmdlen) == NULL)
-		return got_error(GOT_ERR_BAD_PATH);
-
-	/* Forbid linefeeds in paths, like Git does. */
-	if (memchr(&gitcmd[cmdlen + 1], '\n', len - cmdlen) != NULL)
-		return got_error(GOT_ERR_BAD_PATH);
-
-	path0 = strdup(&gitcmd[cmdlen + 1]);
-	if (path0 == NULL)
-		return got_error_from_errno("strdup");
-	path = path0;
-	pathlen = strlen(path);
-
-	/*
-	 * Git clients send a shell command.
-	 * Trim spaces and quotes around the path.
-	 */
-	while (path[0] == '\'' || path[0] == '\"' || path[0] == ' ') {
-		path++;
-		pathlen--;
-	}
-	while (pathlen > 0 &&
-	    (path[pathlen - 1] == '\'' || path[pathlen - 1] == '\"' ||
-	    path[pathlen - 1] == ' ')) {
-		path[pathlen - 1] = '\0';
-		pathlen--;
-	}
-
-	/* Deny an empty repository path. */
-	if (path[0] == '\0' || got_path_is_root_dir(path)) {
-		err = got_error(GOT_ERR_NOT_GIT_REPO);
-		goto done;
-	}
-
-	if (asprintf(&abspath, "/%s", path) == -1) {
-		err = got_error_from_errno("asprintf");
-		goto done;
-	}
-	pathlen = strlen(abspath);
-	canonpath = malloc(pathlen);
-	if (canonpath == NULL) {
-		err = got_error_from_errno("malloc");
-		goto done;
-	}
-	err = got_canonpath(abspath, canonpath, pathlen);
-	if (err)
-		goto done;
-
-	relpath = canonpath;
-	while (relpath[0] == '/')
-		relpath++;
-	*repo_path = strdup(relpath);
-	if (*repo_path == NULL) {
-		err = got_error_from_errno("strdup");
-		goto done;
-	}
-	*command = strndup(gitcmd, cmdlen);
-	if (*command == NULL)
-		err = got_error_from_errno("strndup");
-done:
-	free(path0);
-	free(abspath);
-	free(canonpath);
-	if (err) {
-		free(*repo_path);
-		*repo_path = NULL;
-	}
-	return err;
-}
-
 static const struct got_error *
 append_read_capabilities(size_t *capalen, size_t len, const char *symrefstr,
     uint8_t *buf, size_t bufsize)
@@ -962,8 +865,6 @@ serve_read(int infd, int outfd, int gotd_sock, const char *repo_path,
 				if (err)
 					goto done;
 				seen_have = 1;
-				if (have_ack)
-					curstate = STATE_EXPECT_DONE;
 			}
 		} else if (n == 5 && strncmp(buf, "done\n", 5) == 0) {
 			if (curstate != STATE_EXPECT_HAVE &&
@@ -1479,9 +1380,9 @@ got_serve(int infd, int outfd, const char *command, const char *repo_path,
 {
 	const struct got_error *err = NULL;
 
-	if (strcmp(command, GOT_SERVE_CMD_FETCH) == 0)
+	if (strcmp(command, GOT_DIAL_CMD_FETCH) == 0)
 		err = serve_read(infd, outfd, gotd_sock, repo_path, chattygot);
-	else if (strcmp(command, GOT_SERVE_CMD_SEND) == 0)
+	else if (strcmp(command, GOT_DIAL_CMD_SEND) == 0)
 		err = serve_write(infd, outfd, gotd_sock, repo_path,
 		    chattygot);
 	else
